 /**
  * @Copyright (C) 2020 ~ 2021 KylinSec Co., Ltd. 
  *
  * Author:     liuxinhao <liuxinhao@kylinos.com.cn>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; If not, see <http: //www.gnu.org/licenses/>. 
  */
 
#ifndef QAPPLICATIONDEMO_KIRAN_APPLICATION_H
#define QAPPLICATIONDEMO_KIRAN_APPLICATION_H

#include <QApplication>

/* 重新定义qApp宏，转换QCoreApplication全局单例为KiranApplication, 只在KiranApplication时有效 */
#if defined(qApp)
#undef qApp
#endif
#define qApp (static_cast<KiranApplication*>(QCoreApplication::instance()))

class KiranApplication;
class KiranApplicationPrivate;

/**
 * @brief Kiran对于QApplication的一层封装
 *
 *    实现了以下功能
 *  - 监控字体变化，字体变化时设置应用程序字体,如果有的控件不使用全局字体(需突出显示或者比较小)，
 *    需要通过installEventFilter过滤ApplicationFontChange事件或重写event方法根据全局字体设置相应的字体
 *  - 设置QStyle为KiranStyle,KiranStyle为大部分控件提供了定制,让界面统一
 *
 * 使用说明
 *
 * 　安装 **kiranwidgets-qt5-examples**,详情见/usr/share/kiranwidgets-qt5/examples/kiran-application/
 *
 *  @since 2.1.0
 *  @see QApplication
 *  @todo 监听桌面环境主题变更，主题变化切换Style
 */
class Q_DECL_EXPORT KiranApplication : public QApplication {
    Q_OBJECT
    Q_DECLARE_PRIVATE(KiranApplication)
    Q_DISABLE_COPY(KiranApplication)
public:
    /**
     * @brief KiranApplication构造方法
     * @param argc     同QApplication::QApplication(int &, char **)中argc
     * @param argv     同QApplication::QApplication(int &, char **)中argv
     * @param appFlags 同QApplication::QApplication(int &, char **)中appFlags
     * @see QApplication::QApplication(int &, char **)
     */
    KiranApplication(int &argc, char **argv, int appFlags= ApplicationFlags);

    /**
     * @brief KiranApplication析构方法
     */
    ~KiranApplication();


private:
    /* KiranApplicationPrivate私有类指针 */
    KiranApplicationPrivate *d_ptr;
};


#endif //KIRAN_APPLICATION_H
